from app.models import Severity

PATTERNS = [
    (1, 3, 'Other', Severity.ME, '(?!.*)', '', ''),
    (2, 95, 'Insecure functions', Severity.HI, '(exec\(|eval\(|subprocess\(|popen\(|command\(|system\()', 'The application uses insecure functions that could lead to arbitrary code execution.', 'Try to avoid the usage of insecure functions'),
    (3, 3, 'Storage Operations', Severity.ME, '(openFileOutput|openFileInput|getSharedPreferences|SharedPreferences\.Editor|getCacheDir|getExternalCacheDirs|getExternalStorageState|openOrCreateDatabase|createTempFile|getExternalFilesDir|getExternal|FileOutPutStream|getWritableDatabase|getReadableDatabasegetCacheDir)', 'The application makes storages operations', 'The application must not read or write sensitive information'),
    (4, 3, 'Get network Information', Severity.HI, '(getConnectionInfo|getSSID|getConfiguredNetworks|getNetworkId|getIpAddress|getMacAddressgetNetworkInterfaces|getInetAddresses|getHostAddress)', 'The application is accessing network information', 'The application should access network information only if it is needed'),
    (5, 3, 'Get device Information', Severity.HI, '(getDeviceId|getImei|getMeid|getDeviceSoftwareVersion|getSimSerialNumber|getSimOperator|getLine1Number|getAdvertisingIdInfo|getAdvertisingId)', 'The application is accessing device information', 'The application should access the device information only if it is needed'),
    (6, 3, 'Get GPS Location', Severity.HI, '(getLastKnownLocation|requestLocationUpdates|getLatitude|getLongitude)', 'The application is accessing GPS information', 'The application should GPS information only if it is needed'),
    (7, 3, 'Get applications Information', Severity.ME, '(queryIntentActivities|getInstalledApplications|getInstalledPackages)', 'The application get information about installed application into the device', 'The application should not check other applications into the device'),
    (8, 200, 'Hardcoded IP', Severity.HI, '[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}', 'There are hardcoded IPs into the source code', 'There must not be hardcoded IPs into the source code'),
    (9, 200, 'Hardcoded URLs', Severity.HI, '(http|https|ftp|ftps|file|socket|smtp|pop|imap|jdbc|ldap|ldaps|javascript|data|ssh)://[a-zA-Z0-9./?=_%:-]*', 'There are hardcoded URLs into the source code', 'There must not be hardcoded URLs into the source code'),
    (10, 200, 'Hardcoded Email', Severity.ME, '[w.-]{1,20}@[w-]{1,20}\.[w]{2,10}', 'There are hardcoded emails into the source code', 'There must not be hardcoded emails into the source code'),
    (11, 200, 'Hardcoded DNI', Severity.CR, '(?![.0-9])[0-9]{8}[A-HJ-NP-TV-Z]', 'There are hardcoded NIF into the source code', 'There must not be hardcoded sensitive information into the source code'),
    (12, 312, 'Hardcoded username', Severity.HI, '(admin|login|user|username|usr|usuario|root)s*=s*".*"', 'There are hardcoded users into the source code', 'There must not be hardcoded users into the source code'),
    (13, 312, 'Hardcoded credentials', Severity.CR, '(pass|pwd|password|secret|key|contraseña)s*=s*".*"', 'There are hardcoded passwords into the source code', 'There must not be hardcoded passwords into the source code'),
    (14, 200, 'Hardcoded sensitive info', Severity.ME, '(content:|smtp|pop3|backdoor|vmware|Cryptor\.decrypt\(\(String\).*|DES_KEY\.*=*|SPECIAL_TOKEN*|private\.*\.getBytes|getSecurityString|securityPutString|PUBLIC_KEY.*|LIVE_KEY.*|PRIVATE_KEY.*|api_key|sKEY.=|siv.=|local.*KeySpec|byte\[\]\.*key)', 'There are sensitive information into the source code', 'There must not be sensitive information into the source code'),
    (15, 89, 'Hardcoded connection', Severity.CR, '(://[^ ]{1,$WILDCARD_SHORT}:[^ ]{1,$WILDCARD_SHORT}@|openOrCreateDatabase\()', 'There are hardcoded connections into the source code', 'There must not be hardcoded connections into the source code'),
    (16, 919, 'Web Views', Severity.HI, '(WebView\(|setJavaScriptEnabled\(true|\.addJavascriptInterface\()', 'There are WebViews in the application. Javascript code could be included and could be vulnerable to XSS injections', 'Code in WebViews must be validated to avoid injections'),
    (17, 532, 'Log sensitive information', Severity.LO, '(Log\.(v|d|i|w|e|f|s|wtf)\(|System\.out\.print|System\.err\.print|printStackTrace\()', 'The application is printing information. Check if there are information leak', 'Information on loggers or printed must be validated to avoid internal information leak'),
    (18, 89, 'SQL raw queries', Severity.HI, '(rawQuery\(|execSQL\()', 'App uses SQLite Database and execute raw SQL query. Untrusted user input in raw SQL queries can cause SQL Injection. Also sensitive information should be encrypted and written to the database.', 'Encrypt any sensitive information before saving into database and do not use raw sql queries'),
    (19, 295, 'HTTP Request', Severity.HI, '(HttpsURLConnection|HttpsURLConnection|HttpURLConnection|org\.apache\.http|HttpRequest|HttpPost|HttpClient|HttpResponse|AndroidHttpClient|AbstractHttpClient|URLConnection|openConnection|openStream|TrustAllSSLSocket\-Factory|AllTrustSSLSocketFactory|NonValidatingSSLSocketFactory|SSLCertificateSocketFactory|ALLOW_ALL_HOSTNAME_VERIFIER|\.setDefaultHostnameVerifier\(|NullHostnameVerifier\()', 'The application is making HTTP requests', 'The application may be vulnerable to MITM attacks, check if the connections are secure.'),
    (20, 330, 'Insecure Random Number', Severity.ME, 'java\.util\.Random', 'The application uses an insecure Random Generator', 'The application should use a secure random generator like java.security.SecureRandom'),
    (21, 3, 'Hex decoded', Severity.LO, '([A-F0-9][A-F0-9]|[a-f0-9][a-f0-9]){16,}', 'The application contains HEX data', 'Hex data must never be used as an encryption method'),
    (22, 3, 'Base64 decoded', Severity.LO, '(?:[A-Za-z0-9+/]{4}){2,}(?:[A-Za-z0-9+/]{2}[AEIMQUYcgkosw048]=|[A-Za-z0-9+/][AQgw]==)', 'The application uses Base64 data', 'Hex data must never be used as an encryption method'),
    (23, 780, 'Cipher with no padding', Severity.HI, '\/nopadding', 'This application uses cryptography without padding. The purpose of the padding scheme is to prevent a number of attacks on that only work when the encryption is performed', 'Use padding'),
    (24, 327, 'Cipher with ECB', Severity.LO, '\/ECB', 'The application uses ECB mode in encryption algorithm. ECB mode is known to be weak as it results in the same ciphertext for identical blocks of plaintext.', 'Do not use ECB'),
    (25, 3, 'Send SMS', Severity.HI, '(sendMultipartTextMessage|sendTextMessage|vnd\.android-dir\/mms-sms)', 'The application sends SMS', 'The application should send SMS only if it is needed'),
    (26, 3, 'Read Clipboard data', Severity.HI, '(CLIPBOARD_SERVICE|ClipboardManager|OnPrimaryClipChangedListener|setPrimaryClip)', 'The application reads clipboard data', 'The application should read clipboard data only if it is needed'),
    (27, 327, 'Weak Cryptography', Severity.HI, '(3des|des3|TripleDES|Triple-DES|Cipher.newInstance\s?\(\s?\"DES|Cipher.getInstance\s?\(\s?\"DES)', 'The application is using a weak cryptography algorithm. This means that the application cannot guarantee the confidentiality of sensitive data.', 'Upgrade cryptographic algorithm to secure standards like AES (Advanced Encryption Algorithm).'),
    (28, 327, 'Weak Hash algortithm used', Severity.ME, '(md4|md5|arcfour|rc2|rc4|sha-1|DigestUtils\.sha\(|\.hashCode\()', 'The application is ussing a weak hashing algorithm. They are known to have collisions', 'Use a strong hashing algorithm like sha-2 or sha-512'),
    (29, 329, 'Insecure IV', Severity.ME, '(0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00|0x01,0x02,0x03,0x04,0x05,0x06,0x07)', 'The application uses insecure Initialization Vectors. This makes ciphertext much more predictable and susceptible to a dictionary attack', 'Use a random IV'),
    (30, 276, 'Superuser privileges', Severity.HI, '(com\.noshufou\.android\.su|com\.thirdparty\.superuser|eu\.chainfire\.supersu|com\.koushikdutta\.superuser|eu\.chainfire)', 'The application is requesting superuser privileges', 'The application must never request superuser privileges'),
    (31, 502, 'Insecure Deserialization', Severity.ME, 'com\.fasterxml\.jackson', 'The app uses jackson deserialization library, which is insecure. Deserialization of untrusted input can result in arbitary code execution', 'The application must use a secure deseralization library'),
    (32, 3, 'Media record', Severity.HI, 'android\.media\.MediaRecorder', 'The app records media.', 'The application should record media only if it is needed'),
    (33, 3, 'Uses notifications', Severity.LO, '(android\.app\.NotificationManager)', 'The application uses notifications using Android Notification Manager', ''),
    (34, 3, 'Download files', Severity.LO, '(android\.app\.DownloadManager|getSystemService\(DOWNLOAD_SERVICE\))', 'The application downloads files using Android Download Manager', ''),
    (35, 297, 'Improper Certificate Validation', Severity.ME, '(X509Certificate\[s?\]\s*getAcceptedIssuers\(s?\))', 'The application does not validate, or incorrectly validates, a certificate. If the host is not checked, it is possible for a redirection or spoofing attack to allow a malicious host with a valid certificate to provide data, impersonating a trusted host. In order to ensure data integrity, the certificate must be valid and it must pertain to the site that is being accessed.', 'The certificate\'s host-specific data must be properly checked'),
    (36, 1021, 'Tapjacking', Severity.CR, '(TYPE_SYSTEM_ALERT|FLAG_NOT_TOUCH_MODAL|FLAG_NOT_TOUCHABLE|startOverlayService)', 'The application access methods related to Tapjacking attacks', 'Do not use dangerous methods that could lead to Tapjacking'),
    (37, 396, 'Generic Exceptions', Severity.ME, '\((Error|RuntimeException|Throwable|Exception)', 'Throwing and Catching overly broad exceptions promotes complex error handling code that is more likely to contain security vulnerabilities.', 'Avoid using generic Exceptions'),
    (38, 926, 'Exported Component', Severity.HI, 'android:exported="true"', 'The application exports a component for use by other applications, but does not properly restrict which applications can launch the component or access the data it contains.', 'Because these components have intent filters but have not explicitly set \'android:exported=false\' elsewhere in the manifest, they are automatically exported so that any other application can launch them. This may lead to unintended behavior or exploits.'),
    (39, 530, 'Allow Backup Component', Severity.HI, 'android:allowBackup="true"', 'Android attribute allowBackup allows anyone who can turn on the USB debugging could access application data from the device.', 'The application should turn off the application backup feature, set \'android:allowBackup=false'),
    (40, 250, 'Debuggable Component', Severity.HI, 'android:debuggable="true"', 'If an application is marked as debuggable then any attacker would not need root to access the application data and could run arbitary code under that application permission.', 'The application should turn off the application debuggable feature, set \'android:debuggable=false'),
    (41, 20, 'Injections', Severity.HI, '(getParameterNames\(|getParameter\(|getParameterValues\(|getParamaterMap\()', 'The application manages user input. Check if validation is performed to avoid injections.', 'Make sure that all input are validated and all output is scaped.'),
    (42, 3, 'Prevent exported components', Severity.NO, 'android:exported="false"', 'Unless you intend to send data from your app to a different app that you don\'t own, you should explicitly disallow other developers\' apps from accessing the ContentProvider objects that your app contains.',''),
    (43, 3, 'Prevent Backup components', Severity.NO, 'android:allowBackup="false"', 'Backup is disabled, this mean that anyone with USB debugging could not access application data from the device.',''),
    (44, 3, 'Prevent debuggable components', Severity.NO, 'android:debuggable="false"', 'The application is not marked as debuggable, then any attacker would need root to access the application data and is not able to run arbitary code under that application permission.',''),
    (45, 3, 'Secure Random Number', Severity.NO, 'java\.security\.SecureRandom', 'The application uses an secure Random Generator', ''),
    (46, 3, 'Secure HTTPs Request', Severity.NO, '(HttpsURLConnection|HttpsURLConnection)', 'The application is using TLS to encrypt HTTP communication', ''),
    (47, 3, 'Conection Verification/SSL Pinning', Severity.NO, '(PinningHelper\.getPinnedHttpsURLConnection|PinningHelper\.getPinnedHttpClient|PinningSSLSocketFactory|TrustManager|onReceivedSslError|HostnameVerifier|CertificatePinner)', 'The application verifies the certificate with SSL Pinning', ''),
    (48, 3, 'Cryptography', Severity.NO, '(javax\.crypto|kalium\.crypto|bouncycastle\.crypto|\.Cipher|javax\.crypto\.Mac|\.MessageDigest|\.Signature|\.Key|\.PublicKey|\.SecretKey|\.KeyStore|\.Cipher|\.SecretKeySpec)', 'The application is using cryptography', ''),
    (49, 3, 'Root detection', Severity.NO, '(eu\.chainfire\.supersu|eu\.chainfire\.supersu\.pro|com\.koushikdutta\.superuser|com\.noshufou\.android\.su|exec\("su|\.contains\("test-keys"\)|/system/app/Superuser\.apk|isDeviceRooted|/system/bin/failsafe/su|/system/sd/xbin/su|/system/xbin/whichgt|RootTools\.isAccessGiven\()', 'The application checks if the device has been rooted', ''),
    (50, 3, 'Frida detection', Severity.NO, '(fridaserver|LIBFRIDA)', 'The application checks if the device is using Frida', ''),
    (51, 3, 'Debugger detection', Severity.NO, '(isDebuggable|isDebuggerConnected|isRunningInEmulator|isSignedWithDebugKey)', 'The application checks if the device is debuggable', ''),
    (52, 3, 'Prevent tapjacking', Severity.NO, 'setFilterTouchesWhenObscured\(true\)|onFilterTouchEventForSecurity', 'The application has capabilities to prevent tapjacking attacks', ''),
]